#
# spec file for package luajit
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libluajit-5_1-2
Name:           luajit
Version:        2.0.4
Release:        16.1
Summary:        JIT compiler for Lua language
License:        MIT
Group:          Development/Libraries
Url:            http://www.luajit.com/
Source:         http://luajit.org/download/LuaJIT-%{version}.tar.gz
BuildRequires:  pkg-config
Requires:       %{libname} = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
A Just-In-Time Compiler for Lua language

%package -n %{libname}
Summary:        Library for JIT Lua compiler
Group:          Development/Libraries

%description -n %{libname}
Libraries to use JIT Lua compiler

%package devel
Summary:        Devel files for %{name}
Group:          Development/Languages/Other
Requires:       %{libname} = %{version}
Requires:       %{name} = %{version}

%description devel
Devel files for luajit package

%prep
%setup -q -n LuaJIT-%{version}

# Fix variables
sed -i "s,PREFIX= %{_prefix}/local,PREFIX= %{_prefix}," Makefile
sed -i "s,%{_libexecdir},%{_libdir}," etc/luajit.pc

%build
CFLAGS="%{optflags}" \
make %{?_smp_mflags} \
	Q= \
	DYNAMIC_CC="cc -fPIC" \
	LDCONFIG="true" \
	TARGET_AR="ar rcus"

%install
make DESTDIR=%{buildroot} install \
	INSTALL_LIB="%{buildroot}/%{_libdir}" \
	DYNAMIC_CC="cc -fPIC" \
	LDCONFIG="true" \
	TARGET_AR="ar rcus"
# remove static lib, not needed
rm %{buildroot}/%{_libdir}/*.a

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/%{name}
%{_bindir}/%{name}-%{version}
%{_mandir}/man1/%{name}*
%dir %{_datadir}/%{name}-%{version}/
%{_datadir}/%{name}-%{version}/*

%files -n %{libname}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%dir %{_includedir}/%{name}-2.0/
%{_includedir}/%{name}-2.0/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Wed Jul  1 2015 tchvatal@suse.com
- Version bump to 2.0.4:
  * Fix stack check in narrowing optimization.
  * Fix Lua/C API typecheck error for special indexes.
  * Fix string to number conversion.
  * Fix lexer error for chunks without tokens.
  * Don't compile IR_RETF after CALLT to ff with-side effects.
  * Fix BC_UCLO/BC_JMP join optimization in Lua parser.
  * Fix corner case in string to number conversion.
  * Gracefully handle lua_error() for a suspended coroutine.
  * Avoid error messages when building with Clang.
  * Fix snapshot #0 handling for traces with a stack check on entry.
  * Fix fused constant loads under high register pressure.
  * Invalidate backpropagation cache after DCE.
  * Fix ABC elimination.
  * Fix debug info for main chunk of stripped bytecode.
  * Fix FOLD rule for string.sub(s, ...) == k.
  * Fix FOLD rule for STRREF of SNEW.
  * Fix frame traversal while searching for error function.
  * Prevent GC estimate miscalculation due to buffer growth.
  * Prevent adding side traces for stack checks.
  * Fix top slot calculation for snapshots with continuations.
  * Fix check for reuse of SCEV results in FORL.
  * Add PS Vita port.
  * Fix compatibility issues with Illumos.
  * Fix DragonFly build (unsupported).
  * OpenBSD/x86: Better executable memory allocation for W^X mode.
  * x86: Fix argument checks for ipairs() iterator.
  * x86: lj_math_random_step() clobbers XMM regs on OSX Clang.
  * x86: Fix code generation for unused result of math.random().
  * x64: Allow building with LUAJIT_USE_SYSMALLOC and LUAJIT_USE_VALGRIND.
  * x86/x64: Fix argument check for bit shifts.
  * x86/x64: Fix code generation for fused test/arith ops.
  * ARM: Fix write barrier check in BC_USETS.
  * PPC: Fix red zone overflow in machine code generation.
  * PPC: Don't use mcrxr on PPE.
  * Various archs: Fix excess stack growth in interpreter.
  * FFI: Fix FOLD rule for TOBIT + CONV num.u32.
  * FFI: Prevent DSE across ffi.string().
  * FFI: No meta fallback when indexing pointer to incomplete struct.
  * FFI: Fix initialization of unions of subtypes.
  * FFI: Fix cdata vs. non-cdata arithmetic and comparisons.
  * FFI: Fix __index/__newindex metamethod resolution for ctypes.
  * FFI: Fix compilation of reference field access.
  * FFI: Fix frame traversal for backtraces with FFI callbacks.
  * FFI: Fix recording of indexing a struct pointer ctype object itself.
  * FFI: Allow non-scalar cdata to be compared for equality by address.
  * FFI: Fix pseudo type conversions for type punning.
* Fri Mar 13 2015 tchvatal@suse.com
- Cleanup a bit with spec-cleaner
* Sat Oct 18 2014 mailaender@opensuse.org
- update to version 2.0.3
  * Add support for multilib distro builds.
  * Improve ULOAD forwarding for open upvalues.
  * Fix GC steps threshold handling when called by JIT-compiled code.
  * Fix argument checks for math.deg() and math.rad().
  * Fix jit.flush(func|true).
  * Respect jit.off(func) when returning to a function, too.
  * Fix compilation of string.byte(s, nil, n).
  * Fix line number for relocated bytecode after closure fixup
  * Fix frame traversal for backtraces.
  * Fix ABC elimination.
  * Fix handling of redundant PHIs.
  * Fix snapshot restore for exit to function header.
  * Fix type punning alias analysis for constified pointers
  * Fix call unroll checks in the presence of metamethod frames.
  * Fix initial maxslot for down-recursive traces.
  * Prevent BASE register coalescing if parent uses IR_RETF.
  * Don't purge modified function from stack slots in BC_RET.
  * Fix recording of BC_VARG.
  * Don't access dangling reference to reallocated IR.
  * Fix frame depth display for bytecode dump in -jdump.
  * ARM: Fix register allocation when rematerializing FPRs.
  * x64: Fix store to upvalue for lightuserdata values.
  * FFI: Add missing GC steps for callback argument conversions.
  * FFI: Properly unload loaded DLLs.
  * FFI: Fix argument checks for ffi.string().
  * FFI/x64: Fix passing of vector arguments to calls.
  * FFI: Rehash finalizer table after GC cycle, if needed.
  * FFI: Fix cts->L for cdata unsinking in snapshot restore.
* Thu Apr 17 2014 simon@simotek.net
- %%make_install replaced with make DESTDIR=%%{buildroot} install
  to fix fedora builds
* Wed Oct 23 2013 tchvatal@suse.com
- Export CFLAGS, funny localy it used them properly.
* Wed Oct 23 2013 tchvatal@suse.com
- Drop STRIP=true from the args.
* Wed Oct 23 2013 tchvatal@suse.com
- Change lib group to libraries only.
* Thu Oct 17 2013 tchvatal@suse.com
- Make the thing acutally build&install.
* Thu Oct 17 2013 tchvatal@suse.com
- Inital package. Used in mpv multimedia player.
